@@ -1,6 +1,6 @@
 `PosteriorMode` <-
-function (coordinates, path.mcmc, plotit = TRUE, printit = FALSE, 
-    file, main.title = "") 
+function (coordinates, path.mcmc, plotit = TRUE, format = "pdf", 
+    printit = FALSE, file, main.title = "") 
 {
     coordinates <- as.matrix(coordinates)
     fileparam <- paste(path.mcmc, "parameters.txt", sep = "")
@@ -12,26 +12,15 @@ function (coordinates, path.mcmc, plotit = TRUE, printit = FALSE,
         "postprocess.parameters.txt", sep = "")))
     nxdom <- as.numeric(param.postprocess[1, 3])
     nydom <- as.numeric(param.postprocess[2, 3])
+    print(nxdom)
+    print(nydom)
     s <- coordinates
     filedom <- paste(path.mcmc, "proba.pop.membership.txt", sep = "/")
-    dom.post <- as.matrix(read.table(filedom))[, -(1:2)]
-    coord.grid <- as.matrix(read.table(filedom))[, (1:2)]
+    data <- as.matrix(read.table(filedom))
+    dom.post <- data[, -(1:2)]
+    coord.grid <- data[, (1:2)]
     s[, 1] <- s[, 1] - min(s[, 1])
     s[, 2] <- s[, 2] - min(s[, 2])
-    xlim <- c(min(s[, 1]) - delta.coord/2, max(s[, 1]) + delta.coord/2)
-    ylim <- c(min(s[, 2]) - delta.coord/2, max(s[, 2]) + delta.coord/2)
-    Dx <- (xlim[2] - xlim[1])/(nxdom - 1)
-    Dy <- (ylim[2] - ylim[1])/(nydom - 1)
-    s.discr <- s
-    s.discr[, 1] <- floor(s[, 1]/Dx) * Dx
-    s.discr[, 2] <- floor(s[, 2]/Dy) * Dy
-    is <- s.discr[, 1]/Dx + 1
-    js <- s.discr[, 2]/Dy + 1
-    ks <- (is - 1) * nydom + js
-    map <- numeric(length(ks))
-    for (k in 1:length(ks)) {
-        map[k] <- order(dom.post[ks[k], ], decreasing = TRUE)[1]
-    }
     map.dom <- t(apply(dom.post, 1, order))[, npopmax]
     if (plotit) {
         get(getOption("device"))()
@@ -47,11 +36,17 @@ function (coordinates, path.mcmc, plotit = TRUE, printit = FALSE,
                 1] + delta.coord/2 + frame)), ylim = c(min(coordinates[, 
                 2] - delta.coord/2 - frame), max(coordinates[, 
                 2] + delta.coord/2 + frame)), asp = 1)
+        points(coordinates, pch = 16, cex = 0.2)
         title(sub = "Posterior mode of population membership")
         title(main = main.title, pch = 16)
     }
     if (printit) {
-        postscript(file)
+        if (format == "ps") {
+            postscript(file)
+        }
+        if (format == "pdf") {
+            pdf(file)
+        }
         frame <- max(max(coordinates[, 1]) - min(coordinates[, 
             1]), max(coordinates[, 2]) - min(coordinates[, 2]))/40
         image(seq(min(coordinates[, 1] - delta.coord/2), max(coordinates[, 
@@ -64,7 +59,7 @@ function (coordinates, path.mcmc, plotit = TRUE, printit = FALSE,
                 1] + delta.coord/2 + frame)), ylim = c(min(coordinates[, 
                 2] - delta.coord/2 - frame), max(coordinates[, 
                 2] + delta.coord/2 + frame)), asp = 1)
-        points(coordinates, pch = 16)
+        points(coordinates, pch = 16, cex = 0.2)
         title(main = main.title, sub = "Posterior mode of population membership")
         dev.off()
     }
